@@ -66,35 +66,14 @@ class Request:
             location = normalize_uri(r.headers['location'], self.__redirect_base_url)
         return proxy, location, method
 
-    def _requests_helper(
-            self, method, url, headers=None, data=None,
-            max_redirects=10, **kwargs
-    ) -> requests.Response:
-        self._prepare_redirect_base_url(url)
-        headers = self.__patch_headers(headers)
-        args = {
-            'url': url,
-            'headers': headers,
-            'data': data,
-        }
-        self.__set_defaults(args, kwargs)
-        self.__set_defaults(args, self._get_kwargs())
-        args.setdefault('allow_redirects', False)
-        r = getattr(requests, method)(**args)
+    def _requests_helper(self, method, url, **kwargs) -> requests.Response:
+        r = requests.request(method, url, **kwargs)
+
+        if len(r.history):
+            for i in r.history:
+                self.__update_cookies(i)
         self.__update_cookies(r)
-        if r.is_redirect and method != 'head':
-            if max_redirects < 1:
-                self.debug and print(self._history)
-                raise AttributeError('Too many redirects')
-            self._history.append(url)
-            proxy, location, method = self.__redirect_helper(r, url, method)
-            if proxy:
-                kwargs['proxies'] = proxy
-            return self._requests_helper(
-                method=method, url=location, headers=headers,
-                data=data, max_redirects=(max_redirects - 1),
-                **kwargs
-            )
+
         return r
 
     @staticmethod
