@@ -8,12 +8,12 @@ providers_list = {
     '3asq_info': [
         r'3asq\.info/.',
     ],
+    '_3asq_org': [
+        r'3asq\.org/.',
+    ],
     '7sama_com': [
         r'7sama\.com/manga/.',
     ],
-    # '8muses_com': [
-    #     r'8muses\.com/comics/album/.',
-    # ],
     'ac_qq_com': [
         r'ac\.qq\.com/Comic.+?/id/\d',
     ],
@@ -41,9 +41,6 @@ providers_list = {
     'atfbooru_ninja': [
         r'atfbooru\.ninja/posts.',
     ],
-    # 'authrone_com': [
-    #     r'authrone\.com/manga/.',
-    # ],
     'bato_to': [
         r'bato\.to/(series|chapter)/\d',
     ],
@@ -53,9 +50,6 @@ providers_list = {
     'bns_shounen_ai_net': [
         r'bns\.shounen-ai\.net/read/(series|read)/.',
     ],
-    'boredomsociety_xyz': [
-        r'boredomsociety\.xyz/(titles/info|reader)/\d',
-    ],
     'cdmnet_com_br': [
         r'cdmnet\.com\.br/titulos/.',
     ],
@@ -68,9 +62,6 @@ providers_list = {
     'comicextra_com': [
         r'comicextra\.com/.',
     ],
-    # 'comico_co_id_content': [
-    #     r'comico\.co\.id/content\?contentId=\d',
-    # ],
     'comico_co_id_titles': [
         r'comico\.co\.id/titles/\d',
     ],
@@ -98,8 +89,6 @@ providers_list = {
     'dejameprobar_es': [
         r'dejameprobar\.es/slide/.',
         r'menudo-fansub\.com/slide/.',
-        r'npscan\.mangaea\.net/slide/.',
-        r'snf\.mangaea\.net/slide/.',
         r'yuri-ism\.net/slide/.',
     ],
     'desu_me': [
@@ -108,9 +97,6 @@ providers_list = {
     'digitalteam1_altervista_org': [
         r'digitalteam1\.altervista\.org/reader/read/.',
     ],
-    # 'dm5_com': [
-    #     r'dm5\.com/manhua-.',
-    # ],
     'doujins_com': [
         r'doujins\.com/gallery/.',
         r'doujin-moe\.us/gallery/.',
@@ -118,18 +104,12 @@ providers_list = {
     'e_hentai_org': [
         r'e-hentai\.org/g/\d',
     ],
-    'exhentai_org': [
-        r'exhentai\.org/g/\d',
-    ],
     'fanfox_net': [
         r'fanfox\.net/manga/.',
     ],
     'freeadultcomix_com': [
         r'freeadultcomix\.com/.',
     ],
-    'freemanga_to': [
-        r'freemanga\.to/(manga|chapter)/.',
-    ],
     'funmanga_com': [
         r'funmanga\.com/.',
     ],
@@ -140,7 +120,6 @@ providers_list = {
         r'gomanga\.co/reader/.',
         r'jaiminisbox\.com/reader/.',
         r'kobato\.hologfx\.com/reader/.',
-        # r'atelierdunoir\.org/reader/.',
         r'seinagi\.org/reader/.',
     ],
     'goodmanga_net': [
@@ -158,7 +137,7 @@ providers_list = {
         r'hatigarmscans\.net/manga/.',
     ],
     'heavenmanga_biz': [
-        r'heavenmanga\.\w+/.',
+        r'heavenmanga\.\w{2,7}/.',
     ],
     'hentai2read_com': [
         r'hentai2read\.com/.',
@@ -222,6 +201,9 @@ providers_list = {
         r'isekaiscan\.com/manga/.',
     ],
     'japscan_com': [
+        r'japscan\.cc/.',
+        r'japscan\.com/.',
+        r'japscan\.co/.',
         r'japscan\.to/.',
     ],
     'jurnalu_ru': [
@@ -249,8 +231,8 @@ providers_list = {
         r'manga-v2\.mangavadisi\.org/manga/.',
         r'universoyuri\.com/manga/.',
         r'digitalteam1\.altervista\.org/manga/.',
-        # r'sosscanlation\.com/manga/.',
         r'komikgue\.com/manga/.',
+        r'onma\.me/manga/.',
     ],
     'kumanga_com': [
         r'kumanga\.com/manga/\d',
@@ -287,8 +269,11 @@ providers_list = {
     'mang_as': [
         r'mang\.as/manga/.',
     ],
+    'manga41_com': [
+        r'manga41\.com/manga/.',
+    ],
     'manga_ae': [
-        r'manga\.ae/.',
+        r'mangaae\.com/.',
     ],
     'manga_fox_com': [
         r'manga-fox\.com/.',
@@ -303,15 +288,15 @@ providers_list = {
     'manga_online_com_ua': [
         r'manga-online\.com\.ua/.+html',
     ],
-    'manga_room_com': [
-        r'manga-room\.com/manga/.',
-    ],
     'manga_sh': [
         r'manga\.sh/comics/.',
     ],
     'manga_tube_me': [
         r'manga-tube\.me/series/.',
     ],
+    'mangaarabteam_com': [
+        r'mangaarabteam\.com/.',
+    ],
     'manga_tr_com': [
         r'manga-tr\.com/(manga|id)-.',
     ],
@@ -344,14 +329,8 @@ providers_list = {
         r'manga99\.com/.',
     ],
     'mangadex_org': [
-        r'mangadex\.org/manga/.',
-    ],
-    'mangadex_com': [
-        r'mangadex\.com/(title|chapter)/.',
-        r'mangadex\.org/(title|chapter)/.',
-    ],
-    'mangadex_info': [
-        r'mangadex\.info/manga/.',
+        r'mangadex\.cc/(manga|title)/.',
+        r'mangadex\.org/(manga|title)/.',
     ],
     'mangaeden_com': [
         r'mangaeden\.com/[^/]+/[^/]+-manga/.',
@@ -361,18 +340,12 @@ providers_list = {
         r'mangafans\.us/manga/.',
         r'mangahot\.org/read-manga/.',
     ],
-    # 'mangaforall_com': [
-    #     r'mangaforall\.com/m/.',
-    # ],
     'mangafreak_net_download': [
         r'mangafreak\.net/Manga/.',
     ],
     'mangafull_org': [
         r'mangafull\.org/manga/.',
     ],
-    # 'mangago_me': [
-    #     r'mangago\.me/read-manga/.',
-    # ],
     'mangahasu_se': [
         r'mangahasu\.se/.',
     ],
@@ -399,7 +372,6 @@ providers_list = {
     ],
     'mangahub_io': [
         r'mangahub\.io/(manga|chapter)/.',
-        # r'mangareader\.site/(manga|chapter)/.',
         r'mangakakalot\.fun/(manga|chapter)/.',
         r'mangahere\.onl/(manga|chapter)/.',
     ],
@@ -421,8 +393,10 @@ providers_list = {
     'mangakatana_com': [
         r'mangakatana\.com/manga/.',
     ],
+    'mangakomi_com': [
+        r'mangakomi\.com/manga/.',
+    ],
     'mangaku_web_id': [
-        # r'mangaku\.web\.id/.',
         r'mangaku\.in/.',
     ],
     'mangalib_me': [
@@ -430,6 +404,7 @@ providers_list = {
     ],
     'mangalife_us': [
         r'mangalife\.us/(read-online|manga)/.',
+        r'manga4life\.com/(read-online|manga)/.',
     ],
     'mangamew_com': [
         r'mangamew\.com/(\w+-)?manga/.',
@@ -467,11 +442,6 @@ providers_list = {
     'mangareader_xyz': [
         r'mangareader\.xyz/manga/.',
         r'mangareader\.xyz/.+?/chapter-\d',
-        # r'mangafox\.cc/manga/.',
-        # r'mangafox\.cc/.+?/chapter-\d',
-    ],
-    'mangarock_com': [
-        r'mangarock\.com/manga/.',
     ],
     'mangarussia_com': [
         r'mangarussia\.com/(manga|chapter)/.',
@@ -520,18 +490,9 @@ providers_list = {
     'manhuatai_com': [
         r'manhuatai\.com/.',
     ],
-    'manhwa_co': [
-        r'manhwa\.co/.',
-    ],
-    # 'manhwahentai_com': [
-    #     r'manhwahentai\.com/manhwa/.'
-    # ],
     'merakiscans_com': [
         r'merakiscans\.com/manga/.',
     ],
-    'mintmanga_com': [
-        r'mintmanga\.com/.',
-    ],
     'mngcow_co': [
         r'mngcow\.co/.',
     ],
@@ -568,12 +529,8 @@ providers_list = {
         r'noranofansub\.com(/lector)?/(series/|read/)?.',
     ],
     'nozominofansub_com': [  # mangazuki_co
-        r'nozominofansub\.com/public(/index\.php)?/manga/.',
         r'godsrealmscan\.com/public(/index\.php)?/manga/.',
     ],
-    # 'nude_moon_me': [
-    #     r'nude-moon\.me/\d',
-    # ],
     'otakusmash_com': [
         r'otakusmash\.com/.',
         r'mrsmanga\.com/.',
@@ -634,12 +591,10 @@ providers_list = {
     'read_powermanga_org': [
         r'lector\.dangolinenofansub\.com/(series|read)/.',
         r'read\.powermanga\.org/(series|read)/.',
-        # r'read\.yagami\.me/(series|read)/.',
         r'reader\.kireicake\.com/(series|read)/.',
         r'reader\.shoujosense\.com/(series|read)/.',
         r'reader\.whiteoutscans\.com/(series|read)/.',
         r'slide\.world-three\.org/(series|read)/.',
-        r'manga\.animefrontline\.com/(series|read)/.',
         r'reader\.s2smanga\.com/(series|read)/.',
         r'reader\.seaotterscans\.com/(series|read)/.',
         r'reader\.idkscans\.com/(series|read)/.',
@@ -662,14 +617,6 @@ providers_list = {
     'read_yagami_me': [
         r'read\.yagami\.me/series/\w',
     ],
-    # 'readcomicbooksonline_org_manga': [  # todo #168
-    #     r'readcomicbooksonline\.net/manga/.',
-    #     r'readcomicbooksonline\.org/manga/.',
-    # ],
-    # 'readcomicbooksonline_org': [
-    #     r'readcomicbooksonline\.net/.',
-    #     r'readcomicbooksonline\.org/.',
-    # ],
     'comicpunch_net_manga': [
         r'comicpunch\.net/asiancomics/.',
     ],
@@ -682,9 +629,6 @@ providers_list = {
     'reader_imangascans_org': [
         r'reader\.imangascans\.org/.',
     ],
-    # 'readhentaimanga_com': [
-    #     r'readhentaimanga\.com/.',
-    # ],
     'readcomiconline_to': [
         r'readcomiconline\.to/Comic/.',
     ],
@@ -693,6 +637,8 @@ providers_list = {
     ],
     'readmanga_me': [
         r'readmanga\.me/.',
+        r'mintmanga\.com/.',
+        r'selfmanga\.ru/.',
     ],
     'readmanga_eu': [
         r'readmanga\.eu/manga/\d+/.',
@@ -703,15 +649,13 @@ providers_list = {
     'readms_net': [
         r'readms\.net/(r|manga)/.',
     ],
+    # todo #266
     'remanga_org': [
         r'remanga\.org/manga/.',
     ],
     'santosfansub_com': [
         r'santosfansub\.com/Slide/.',
     ],
-    'selfmanga_ru': [
-        r'selfmanga\.ru/.',
-    ],
     'senmanga_com': [
         r'senmanga\.com/.',
     ],
@@ -731,13 +675,7 @@ providers_list = {
     'sleepypandascans_co': [
         r'sleepypandascans\.co/(Series|Reader)/.',
     ],
-    #'somanga_net': [
-    #    r'somanga\.net/(leitor|manga)/.',
-    #    r'somangas\.net/(leitor|manga)/.',
-    #],
     'subapics_com': [
-        # r'subapics\.com/manga/.',
-        # r'subapics\.com/.+-chapter-.',
         r'mangakita\.net/manga/.',
         r'mangakita\.net/.+-chapter-.',
         r'komikstation\.com/manga/.',
@@ -799,10 +737,6 @@ providers_list = {
         r'tsumino\.com/Book/Info/\d',
         r'tsumino\.com/Read/View/\d',
     ],
-    # 'tumangaonline_com': [
-    #     r'tumangaonline\.com/.',
-    #     r'tumangaonline\.me/.',
-    # ],
     'unionmangas_net': [
         r'unionmangas\.cc/(leitor|manga)/.',
         r'unionmangas\.net/(leitor|manga)/.',
@@ -846,9 +780,6 @@ providers_list = {
     'zingbox_me': [
         r'zingbox\.me/.',
     ],
-    'zip_read_com': [
-        r'zip-read\.com/.',
-    ],
     'zmanga_net': [
         r'zmanga\.net/.',
     ],
