@@ -48,9 +48,5 @@ class GoMangaCo(Provider, Std):
         except Exception:
             pass
 
-    def book_meta(self) -> dict:
-        # todo meta
-        pass
-
 
 main = GoMangaCo
