@@ -11,7 +11,7 @@ class MyReadingMangaInfo(Provider, Std):
         return self._get_content('{}/{}/')
 
     def get_manga_name(self) -> str:
-        return self._get_name(r'\.info/([^/]+)')
+        return self._get_name(r'\.\w{2,7}/([^/]+)')
 
     def get_chapters(self):
         v = [self.get_url()]  # current chapter
