@@ -15,7 +15,7 @@ class SoMangaNet(Provider, Std):
         return self._get_content('{}/manga/{}')
 
     def get_manga_name(self) -> str:
-        return self._get_name(r'\.net/[^/]+/([^/]+)')
+        return self._get_name(r'\.\w{2,7}/[^/]+/([^/]+)')
 
     def get_chapters(self):
         return self._elements('ul.capitulos li > a')
