@@ -12,8 +12,6 @@ class SundayWebryCom(Provider, Std):
         return self.re.search(r'cti=([^&]*)', self.chapter).group(1)
 
     def get_main_content(self):
-        if self._storage.get('main_content', None):
-            return self._storage.get('main_content')
         return self.http_get('{}/series/{}'.format(
             self.domain,
             self._get_name(r'/series/(\d+)')
